@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2015 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sessionthread_p.h"
@@ -49,10 +36,6 @@ static const sasl_callback_t callbacks[] = {
 SessionThread::SessionThread(Session *session, QObject *parent)
     : QObject(parent)
     , m_session(session)
-    , m_sasl_conn(nullptr)
-    , m_sasl_client_interact(nullptr)
-    , m_pendingQuantity(-1)
-    , m_sslCheck(nullptr)
 {
     static bool saslInitialized = false;
     if (!saslInitialized) {
@@ -61,7 +44,7 @@ SessionThread::SessionThread(Session *session, QObject *parent)
         saslInitialized = true;
     }
 
-    QThread *thread = new QThread();
+    auto *thread = new QThread();
     moveToThread(thread);
     thread->start();
     QMetaObject::invokeMethod(this, "doInit");
@@ -214,13 +197,13 @@ void SessionThread::slotSocketError()
 {
     Q_ASSERT(QThread::currentThread() == thread());
 
-    qCWarning(KMANAGERSIEVE_LOG) << Q_FUNC_INFO <<
-                                    m_socket->error()
+    qCWarning(KMANAGERSIEVE_LOG) << Q_FUNC_INFO
+                                 <<m_socket->error()
                                  << m_socket->errorString();
 
     Q_EMIT error(
-                m_socket->error()
-                , m_socket->errorString());
+        m_socket->error(),
+        m_socket->errorString());
     doDisconnectFromHost(false);
 }
 
@@ -322,7 +305,7 @@ bool SessionThread::saslInteract(void *in)
     Q_ASSERT(QThread::currentThread() == thread());
 
     qCDebug(KMANAGERSIEVE_LOG) << "SessionThread::saslInteract";
-    sasl_interact_t *interact = (sasl_interact_t *)in;
+    auto *interact = (sasl_interact_t *)in;
 
     //some mechanisms do not require username && pass, so it doesn't need a popup
     //window for getting this info
