@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "autocreatescriptdialog.h"
@@ -35,9 +22,10 @@ using namespace KSieveUi;
 
 AutoCreateScriptDialog::AutoCreateScriptDialog(QWidget *parent)
     : QDialog(parent)
+    , mEditor(new SieveEditorGraphicalModeWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Create Sieve Filter"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -45,7 +33,6 @@ AutoCreateScriptDialog::AutoCreateScriptDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AutoCreateScriptDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AutoCreateScriptDialog::reject);
     okButton->setFocus();
-    mEditor = new SieveEditorGraphicalModeWidget(this);
     mainLayout->addWidget(mEditor);
     mainLayout->addWidget(buttonBox);
     readConfig();
@@ -100,7 +87,7 @@ bool AutoCreateScriptDialog::event(QEvent *e)
 {
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        QKeyEvent *kev = static_cast<QKeyEvent * >(e);
+        auto *kev = static_cast<QKeyEvent * >(e);
         if (kev->key() == Qt::Key_Escape) {
             e->ignore();
             return true;
