@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "selectconvertparameterwidget.h"
 
@@ -53,10 +40,10 @@ void SelectConvertParameterWidget::setCode(const QStringList &code, QString &err
     }
 
     QString widthStr = code.at(0);
-    widthStr = widthStr.remove(QStringLiteral("pix-x="));
+    widthStr.remove(QStringLiteral("pix-x="));
 
     QString heightStr = code.at(1);
-    heightStr = heightStr.remove(QStringLiteral("pix-y="));
+    heightStr.remove(QStringLiteral("pix-y="));
     mWidth->setValue(widthStr.toInt());
     mHeight->setValue(heightStr.toInt());
 }
@@ -69,7 +56,7 @@ QString SelectConvertParameterWidget::code() const
 void SelectConvertParameterWidget::initialize()
 {
     QBoxLayout *hbox = new QHBoxLayout(this);
-    hbox->setContentsMargins(0, 0, 0, 0);
+    hbox->setContentsMargins({});
     mWidth = new QSpinBox(this);
     mWidth->setSuffix(i18n(" px"));
     mWidth->setMinimum(1);
