@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionconvert.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -37,14 +24,14 @@ SieveActionConvert::SieveActionConvert(SieveEditorGraphicalModeWidget *sieveGrap
 QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *lay = new QGridLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QGridLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
     QLabel *lab = new QLabel(i18n("From:"));
     lay->addWidget(lab, 0, 0);
 
-    SelectMimeTypeComboBox *fromMimeType = new SelectMimeTypeComboBox;
+    auto *fromMimeType = new SelectMimeTypeComboBox;
     connect(fromMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveActionConvert::valueChanged);
     fromMimeType->setObjectName(QStringLiteral("from"));
     lay->addWidget(fromMimeType, 0, 1);
@@ -52,7 +39,7 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("To:"));
     lay->addWidget(lab, 0, 2);
 
-    SelectMimeTypeComboBox *toMimeType = new SelectMimeTypeComboBox;
+    auto *toMimeType = new SelectMimeTypeComboBox;
     connect(toMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveActionConvert::valueChanged);
     toMimeType->setObjectName(QStringLiteral("to"));
     lay->addWidget(toMimeType, 0, 3);
@@ -60,7 +47,7 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Parameters:"));
     lay->addWidget(lab, 1, 0);
 
-    SelectConvertParameterWidget *params = new SelectConvertParameterWidget;
+    auto *params = new SelectConvertParameterWidget;
     connect(params, &SelectConvertParameterWidget::valueChanged, this, &SieveActionConvert::valueChanged);
     params->setObjectName(QStringLiteral("params"));
     lay->addWidget(params, 1, 1, 2, 3);
@@ -68,17 +55,17 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     int index = 0;
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                SelectMimeTypeComboBox *fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
+                auto *fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
                 fromMimeType->setCode(element.readElementText(), name(), error);
             } else if (index == 1) {
-                SelectMimeTypeComboBox *toMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("to"));
+                auto *toMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("to"));
                 toMimeType->setCode(element.readElementText(), name(), error);
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -86,7 +73,7 @@ bool SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
             ++index;
         } else if (tagName == QLatin1String("list")) {
-            SelectConvertParameterWidget *params = w->findChild<SelectConvertParameterWidget *>(QStringLiteral("params"));
+            auto *params = w->findChild<SelectConvertParameterWidget *>(QStringLiteral("params"));
             params->setCode(AutoCreateScriptUtil::listValue(element), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -99,8 +86,6 @@ bool SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget
             qCDebug(LIBKSIEVE_LOG) << "SieveActionConvert::setParamWidgetValue unknown tag " << tagName;
         }
     }
-
-    return true;
 }
 
 QString SieveActionConvert::code(QWidget *w) const
