@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionnotify.h"
 #include "editor/sieveeditorutil.h"
@@ -39,11 +26,11 @@ SieveActionNotify::SieveActionNotify(SieveEditorGraphicalModeWidget *sieveGraphi
 QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectImportanceCombobox *importanceCombobox = new SelectImportanceCombobox;
+    auto *importanceCombobox = new SelectImportanceCombobox;
     importanceCombobox->setObjectName(QStringLiteral("importancecombo"));
     connect(importanceCombobox, &SelectImportanceCombobox::valueChanged, this, &SieveActionNotify::valueChanged);
     lay->addWidget(importanceCombobox);
@@ -51,7 +38,7 @@ QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
     QLabel *lab = new QLabel(i18n("message:"));
     lay->addWidget(lab);
 
-    QLineEdit *message = new QLineEdit;
+    auto *message = new QLineEdit;
     message->setObjectName(QStringLiteral("message"));
     connect(message, &QLineEdit::textChanged, this, &SieveActionNotify::valueChanged);
     lay->addWidget(message);
@@ -59,7 +46,7 @@ QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("method:"));
     lay->addWidget(lab);
 
-    QLineEdit *method = new QLineEdit;
+    auto *method = new QLineEdit;
     method->setObjectName(QStringLiteral("method"));
     lay->addWidget(method);
     connect(method, &QLineEdit::textChanged, this, &SieveActionNotify::valueChanged);
@@ -67,7 +54,7 @@ QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
@@ -76,13 +63,13 @@ bool SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *
             if (tagValue == QLatin1String("message")) {
                 const QString strValue = AutoCreateScriptUtil::strValue(element);
                 if (!strValue.isEmpty()) {
-                    QLineEdit *message = w->findChild<QLineEdit *>(QStringLiteral("message"));
+                    auto *message = w->findChild<QLineEdit *>(QStringLiteral("message"));
                     message->setText(AutoCreateScriptUtil::quoteStr(strValue));
                 }
             } else if (tagValue == QLatin1String("importance")) {
                 const QString strValue = AutoCreateScriptUtil::strValue(element);
                 if (!strValue.isEmpty()) {
-                    SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox *>(QStringLiteral("importancecombo"));
+                    auto *importance = w->findChild<SelectImportanceCombobox *>(QStringLiteral("importancecombo"));
                     importance->setCode(strValue, name(), error);
                 }
             } else {
@@ -96,15 +83,13 @@ bool SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *
             element.skipCurrentElement();
             //implement in the future ?
         } else if (tagName == QLatin1String("str")) {
-            QLineEdit *method = w->findChild<QLineEdit *>(QStringLiteral("method"));
+            auto *method = w->findChild<QLineEdit *>(QStringLiteral("method"));
             method->setText(AutoCreateScriptUtil::quoteStr(element.readElementText()));
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagName " << tagName;
         }
     }
-
-    return true;
 }
 
 QString SieveActionNotify::code(QWidget *w) const
