@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionreject.h"
 #include "editor/sieveeditorutil.h"
@@ -37,26 +24,26 @@ SieveActionReject::SieveActionReject(SieveEditorGraphicalModeWidget *sieveGraphi
 QWidget *SieveActionReject::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
     QLabel *lab = new QLabel(i18n("text:"));
     lay->addWidget(lab);
 
-    MultiLineEdit *edit = new MultiLineEdit;
+    auto *edit = new MultiLineEdit;
     connect(edit, &MultiLineEdit::textChanged, this, &SieveActionReject::valueChanged);
     edit->setObjectName(QStringLiteral("rejectmessage"));
     lay->addWidget(edit);
     return w;
 }
 
-bool SieveActionReject::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionReject::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            MultiLineEdit *edit = w->findChild<MultiLineEdit *>(QStringLiteral("rejectmessage"));
+            auto *edit = w->findChild<MultiLineEdit *>(QStringLiteral("rejectmessage"));
             edit->setPlainText(tagValue);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -69,7 +56,6 @@ bool SieveActionReject::setParamWidgetValue(QXmlStreamReader &element, QWidget *
             qCDebug(LIBKSIEVE_LOG) << " SieveActionReject::setParamWidgetValue unknown tagName " << tagName;
         }
     }
-    return true;
 }
 
 QString SieveActionReject::code(QWidget *w) const
