@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionbody.h"
 #include "widgets/selectbodytypewidget.h"
@@ -37,16 +24,16 @@ SieveConditionBody::SieveConditionBody(SieveEditorGraphicalModeWidget *sieveGrap
 QWidget *SieveConditionBody::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectBodyTypeWidget *bodyType = new SelectBodyTypeWidget;
+    auto *bodyType = new SelectBodyTypeWidget;
     bodyType->setObjectName(QStringLiteral("bodytype"));
     connect(bodyType, &SelectBodyTypeWidget::valueChanged, this, &SieveConditionBody::valueChanged);
     lay->addWidget(bodyType);
 
-    SelectMatchTypeComboBox *matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto *matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     lay->addWidget(matchType);
     matchType->setObjectName(QStringLiteral("matchtype"));
     connect(matchType, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionBody::valueChanged);
@@ -142,13 +129,13 @@ void SieveConditionBody::setParamWidgetValue(QXmlStreamReader &element, QWidget
     }
     QString errorStr;
     if (strValue.count() == 1) {
-        SelectBodyTypeWidget *bodyType = w->findChild<SelectBodyTypeWidget *>(QStringLiteral("bodytype"));
+        auto *bodyType = w->findChild<SelectBodyTypeWidget *>(QStringLiteral("bodytype"));
         bodyType->setCode(tagValueList.at(0), QString(), name(), errorStr);
         if (errorStr.isEmpty()) {
-            SelectMatchTypeComboBox *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             matchType->setCode(tagValueList.at(1), name(), error);
         } else {
-            SelectMatchTypeComboBox *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             if (tagValueList.count() == 1) {
                 matchType->setCode(tagValueList.at(0), name(), error);
             } else if (tagValueList.count() == 2) {
@@ -156,19 +143,19 @@ void SieveConditionBody::setParamWidgetValue(QXmlStreamReader &element, QWidget
                 bodyType->setCode(tagValueList.at(1), QString(), name(), errorStr);
             }
         }
-        AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("edit"));
+        auto *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("edit"));
         edit->setCode(wasListElement ? strValue.at(0) : AutoCreateScriptUtil::quoteStr(strValue.at(0)));
     } else if (strValue.count() == 2) {
-        SelectBodyTypeWidget *bodyType = w->findChild<SelectBodyTypeWidget *>(QStringLiteral("bodytype"));
+        auto *bodyType = w->findChild<SelectBodyTypeWidget *>(QStringLiteral("bodytype"));
         bodyType->setCode(tagValueList.at(0), indexStr == 2 ? strValue.at(0) : QString(), name(), errorStr);
-        SelectMatchTypeComboBox *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+        auto *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
         if (!errorStr.isEmpty()) {
             matchType->setCode(tagValueList.at(0), name(), error);
             bodyType->setCode(tagValueList.at(1), indexStr == 2 ? strValue.at(0) : QString(), name(), error);
         } else {
             matchType->setCode(tagValueList.at(1), name(), error);
         }
-        AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("edit"));
+        auto *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("edit"));
         edit->setCode(indexStr == 1 ? AutoCreateScriptUtil::quoteStr(strValue.at(0)) : AutoCreateScriptUtil::quoteStr(strValue.at(1)));
     }
 }
