@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionmailboxexists.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -36,11 +23,11 @@ SieveConditionMailboxExists::SieveConditionMailboxExists(SieveEditorGraphicalMod
 QWidget *SieveConditionMailboxExists::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    QLineEdit *edit = new QLineEdit;
+    auto *edit = new QLineEdit;
     connect(edit, &QLineEdit::textChanged, this, &SieveConditionMailboxExists::valueChanged);
     edit->setClearButtonEnabled(true);
     lay->addWidget(edit);
@@ -77,14 +64,14 @@ QString SieveConditionMailboxExists::help() const
         "The \"mailboxexists\" test is true if all mailboxes listed in the \"mailbox-names\" argument exist in the mailstore, and each allows the user in whose context the Sieve script runs to \"deliver\" messages into it.");
 }
 
-bool SieveConditionMailboxExists::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
+void SieveConditionMailboxExists::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
     QString commentStr;
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("edit"));
+            auto *edit = w->findChild<QLineEdit *>(QStringLiteral("edit"));
             edit->setText(AutoCreateScriptUtil::quoteStr(tagValue));
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -99,8 +86,6 @@ bool SieveConditionMailboxExists::setParamWidgetValue(QXmlStreamReader &element,
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-
-    return true;
 }
 
 QUrl SieveConditionMailboxExists::href() const
