@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionvirustest.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -39,21 +26,21 @@ SieveConditionVirusTest::SieveConditionVirusTest(SieveEditorGraphicalModeWidget
 QWidget *SieveConditionVirusTest::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QVBoxLayout *lay = new QVBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QVBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    SelectRelationalMatchType *relation = new SelectRelationalMatchType;
+    auto *relation = new SelectRelationalMatchType;
     connect(relation, &SelectRelationalMatchType::valueChanged, this, &SieveConditionVirusTest::valueChanged);
     relation->setObjectName(QStringLiteral("relation"));
     lay->addWidget(relation);
 
-    SelectComparatorComboBox *comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
+    auto *comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
     connect(comparator, &SelectComparatorComboBox::valueChanged, this, &SieveConditionVirusTest::valueChanged);
     comparator->setObjectName(QStringLiteral("comparator"));
     lay->addWidget(comparator);
 
-    QSpinBox *spinbox = new QSpinBox;
+    auto *spinbox = new QSpinBox;
     spinbox->setMaximum(5);
     spinbox->setMinimum(0);
     spinbox->setObjectName(QStringLiteral("value"));
@@ -103,7 +90,7 @@ QString SieveConditionVirusTest::help() const
     return i18n("Sieve implementations that implement the \"virustest\" test have an identifier of \"virustest\" for use with the capability mechanism.");
 }
 
-bool SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
+void SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
     QString commentStr;
     while (element.readNextStartElement()) {
@@ -114,14 +101,14 @@ bool SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWi
             if (tagValue == QLatin1String("count") || tagValue == QLatin1String("value")) {
                 if (element.readNextStartElement()) {
                     if (element.name() == QLatin1String("str")) {
-                        SelectRelationalMatchType *relation = w->findChild<SelectRelationalMatchType *>(QStringLiteral("relation"));
+                        auto *relation = w->findChild<SelectRelationalMatchType *>(QStringLiteral("relation"));
                         relation->setCode(AutoCreateScriptUtil::tagValue(tagValue), element.readElementText(), name(), error);
                     }
                 }
             } else if (tagValue == QLatin1String("comparator")) {
                 if (element.readNextStartElement()) {
                     if (element.name() == QLatin1String("str")) {
-                        SelectComparatorComboBox *comparator = w->findChild<SelectComparatorComboBox *>(QStringLiteral("comparator"));
+                        auto *comparator = w->findChild<SelectComparatorComboBox *>(QStringLiteral("comparator"));
                         comparator->setCode(element.readElementText(), name(), error);
                     }
                 }
@@ -130,7 +117,7 @@ bool SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWi
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionVirusTest::setParamWidgetValue unknown tagValue " << tagValue;
             }
         } else if (tagName == QLatin1String("str")) {
-            QSpinBox *spinbox = w->findChild<QSpinBox *>(QStringLiteral("value"));
+            auto *spinbox = w->findChild<QSpinBox *>(QStringLiteral("value"));
             spinbox->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -145,8 +132,6 @@ bool SieveConditionVirusTest::setParamWidgetValue(QXmlStreamReader &element, QWi
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-
-    return true;
 }
 
 QUrl SieveConditionVirusTest::href() const
