@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveeditorgraphicalmodewidget.h"
@@ -39,8 +26,8 @@ using namespace KSieveUi;
 SieveEditorGraphicalModeWidget::SieveEditorGraphicalModeWidget(QWidget *parent)
     : SieveEditorGraphicalModeWidgetAbstract::SieveEditorGraphicalModeWidgetAbstract(parent)
 {
-    QVBoxLayout *vlay = new QVBoxLayout(this);
-    vlay->setContentsMargins(0, 0, 0, 0);
+    auto *vlay = new QVBoxLayout(this);
+    vlay->setContentsMargins({});
 
     mSplitter = new QSplitter;
     mSplitter->setChildrenCollapsible(false);
@@ -80,9 +67,7 @@ void SieveEditorGraphicalModeWidget::loadScript(const QString &doc, QString &err
 void SieveEditorGraphicalModeWidget::readConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "AutoCreateScriptDialog");
-    const QList<int> size {
-        100, 400
-    };
+    const QList<int> size { 100, 400 };
     mSplitter->setSizes(group.readEntry("mainSplitter", size));
 }
 
@@ -102,7 +87,7 @@ QStringList SieveEditorGraphicalModeWidget::sieveCapabilities()
     return mCapabilities;
 }
 
-QString SieveEditorGraphicalModeWidget::script(QString &required) const
+QString SieveEditorGraphicalModeWidget::script(QStringList &required) const
 {
     return mSieveScript->generatedScript(required);
 }
@@ -126,10 +111,10 @@ void SieveEditorGraphicalModeWidget::slotActivateScriptPage(QWidget *page)
 
 QString SieveEditorGraphicalModeWidget::currentscript()
 {
-    QString requireModules;
+    QStringList requireModules;
     QString script = mSieveScript->generatedScript(requireModules);
     if (!requireModules.isEmpty()) {
-        script.prepend(requireModules + QLatin1Char('\n'));
+        script.prepend(requireModules.join(QLatin1Char('\n')) + QStringLiteral("\n\n"));
     }
     return script;
 }
