@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sieveeditormenubar.h"
@@ -112,7 +101,6 @@ void SieveEditorMenuBar::initMenus()
     mFileMenu->addAction(mPrintAction);
     mFileMenu->addAction(mPrintPreviewAction);
     mEditorMenu = addMenu(i18nc("@title:menu", "Edit"));
-    mToolsMenu = addMenu(i18nc("@title:menu", "Tools"));
     mEditorMenu->addAction(mUndoAction);
     mEditorMenu->addAction(mRedoAction);
     mEditorMenu->addSeparator();
@@ -127,15 +115,18 @@ void SieveEditorMenuBar::initMenus()
     mEditorMenu->addSeparator();
     mEditorMenu->addAction(mGoToLine);
     mEditorMenu->addSeparator();
-    mEditorMenu->addAction(mZoomInAction);
-    mEditorMenu->addAction(mZoomOutAction);
-    mEditorMenu->addAction(mZoomResetAction);
-    mEditorMenu->addSeparator();
     mEditorMenu->addAction(mWordWrapAction);
+    mEditorMenu->addSeparator();
+    mEditorMenu->addAction(mCommentCodeAction);
+    mEditorMenu->addAction(mUncommentCodeAction);
 
-    mToolsMenu->addAction(mCommentCodeAction);
-    mToolsMenu->addAction(mUncommentCodeAction);
-    mToolsMenu->addSeparator();
+    mViewMenu = addMenu(i18nc("@title:menu", "View"));
+    mViewMenu->addAction(mZoomInAction);
+    mViewMenu->addAction(mZoomOutAction);
+    mViewMenu->addSeparator();
+    mViewMenu->addAction(mZoomResetAction);
+
+    mToolsMenu = addMenu(i18nc("@title:menu", "Tools"));
     mToolsMenu->addAction(mDebugSieveAction);
 }
 
@@ -168,6 +159,11 @@ void SieveEditorMenuBar::slotUpdateActions()
     mPrintPreviewAction->setEnabled(!hasActionInHtmlModeToo);
 }
 
+QMenu *SieveEditorMenuBar::viewMenu() const
+{
+    return mViewMenu;
+}
+
 void SieveEditorMenuBar::setTextModeWidget(SieveEditorTextModeWidget *textModeWidget)
 {
     if (!mTextModeWidget) {
