@@ -1,19 +1,6 @@
-/* Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef SIEVEEDITORTEXTMODEWIDGET_H
@@ -32,7 +19,6 @@ class TextToSpeechWidget;
 }
 
 namespace KSieveUi {
-class SieveInfoWidget;
 class SieveTextEdit;
 class SieveEditorWarning;
 class SieveEditorParsingMissingFeatureWarning;
@@ -105,6 +91,8 @@ public:
     Q_REQUIRED_RESULT SieveEditorTabWidget *tabWidget() const;
 
     void setListOfIncludeFile(const QStringList &listOfIncludeFile);
+    Q_REQUIRED_RESULT QStringList sieveCapabilities() const;
+
 Q_SIGNALS:
     void enableButtonOk(bool);
     void switchToGraphicalMode();
@@ -123,7 +111,10 @@ private:
     void slotGoToLine(int line);
     void readConfig();
     void writeConfig();
-    bool loadFromFile(const QString &filename);
+    void slotEditRule(const QString &selectedText);
+    void slotInsertRule();
+    void insertRequires(const QStringList &needToAddRequire);
+    Q_REQUIRED_RESULT QStringList insertNecessaryRequires(const QStringList &requireModules);
     QString mOriginalScript;
     QStringList mSieveCapabilities;
     QStringList mListOfIncludeFile;
@@ -131,9 +122,7 @@ private:
     KPIMTextEdit::PlainTextEditorWidget *mDebugTextEdit = nullptr;
     KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
-    SieveInfoWidget *mSieveInfo = nullptr;
     QSplitter *mMainSplitter = nullptr;
-    QSplitter *mExtraSplitter = nullptr;
     QSplitter *mTemplateSplitter = nullptr;
     SieveEditorWarning *mSieveEditorWarning = nullptr;
     SieveEditorParsingMissingFeatureWarning *mSieveParsingWarning = nullptr;
