@@ -1,19 +1,6 @@
-/* Copyright (C) 2011-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KSIEVE_KSIEVEUI_SIEVETEXTEDIT_H
@@ -21,7 +8,7 @@
 
 #include "ksieveui_export.h"
 
-#include "kpimtextedit/plaintexteditor.h"
+#include <KPIMTextEdit/PlainTextEditor>
 
 class QMenu;
 namespace KSieveUi {
@@ -66,16 +53,19 @@ protected:
     void createHighlighter() override;
 Q_SIGNALS:
     void openHelp(const QUrl &url);
+    void editRule(const QString &selectedText);
+    void insertRule();
 
 private:
     void slotUpdateLineNumberAreaWidth(int newBlockCount);
     void slotUpdateLineNumberArea(const QRect &, int);
     void slotHelp();
-    bool openVariableHelp();
+    void slotEditRule();
+    Q_REQUIRED_RESULT bool openVariableHelp();
     bool overrideShortcut(QKeyEvent *event);
-    QStringList completerList() const;
+    Q_REQUIRED_RESULT QStringList completerList() const;
     void setCompleterList(const QStringList &list);
-    QString selectedWord(const QPoint &pos = QPoint()) const;
+    Q_REQUIRED_RESULT QString selectedWord(const QPoint &pos = QPoint()) const;
 
     SieveTextEditPrivate *const d;
 };
