@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "findbarbasetest.h"
@@ -39,22 +26,22 @@ FindBarBaseTest::~FindBarBaseTest()
 void FindBarBaseTest::shouldHaveDefaultValue()
 {
     KSieveUi::FindBarBase bar;
-    QLabel *status = bar.findChild<QLabel *>(QStringLiteral("status"));
+    auto *status = bar.findChild<QLabel *>(QStringLiteral("status"));
     QVERIFY(status);
     QVERIFY(status->text().isEmpty());
 
-    QPushButton *previous = bar.findChild<QPushButton *>(QStringLiteral("findprevious"));
+    auto *previous = bar.findChild<QPushButton *>(QStringLiteral("findprevious"));
     QVERIFY(previous);
     QVERIFY(!previous->isEnabled());
 
-    QPushButton *next = bar.findChild<QPushButton *>(QStringLiteral("findnext"));
+    auto *next = bar.findChild<QPushButton *>(QStringLiteral("findnext"));
     QVERIFY(next);
     QVERIFY(!next->isEnabled());
 
-    QToolButton *close = bar.findChild<QToolButton *>(QStringLiteral("close"));
+    auto *close = bar.findChild<QToolButton *>(QStringLiteral("close"));
     QVERIFY(close);
 
-    PimCommon::LineEditWithCompleterNg *lineedit = bar.findChild<PimCommon::LineEditWithCompleterNg *>(QStringLiteral("searchline"));
+    auto *lineedit = bar.findChild<PimCommon::LineEditWithCompleterNg *>(QStringLiteral("searchline"));
     QVERIFY(lineedit);
     QVERIFY(lineedit->text().isEmpty());
 }
@@ -67,7 +54,7 @@ void FindBarBaseTest::shouldClearLineWhenClose()
     QVERIFY(QTest::qWaitForWindowExposed(&bar));
     QVERIFY(bar.isVisible());
     bar.focusAndSetCursor();
-    PimCommon::LineEditWithCompleterNg *lineedit = bar.findChild<PimCommon::LineEditWithCompleterNg *>(QStringLiteral("searchline"));
+    auto *lineedit = bar.findChild<PimCommon::LineEditWithCompleterNg *>(QStringLiteral("searchline"));
     lineedit->setText(QStringLiteral("FOO"));
     QVERIFY(!lineedit->text().isEmpty());
     QVERIFY(lineedit->hasFocus());
@@ -82,9 +69,9 @@ void FindBarBaseTest::shouldEnableDisableNextPreviousButton()
     KSieveUi::FindBarBase bar;
     bar.show();
     QVERIFY(QTest::qWaitForWindowExposed(&bar));
-    QPushButton *previous = bar.findChild<QPushButton *>(QStringLiteral("findprevious"));
+    auto *previous = bar.findChild<QPushButton *>(QStringLiteral("findprevious"));
 
-    QPushButton *next = bar.findChild<QPushButton *>(QStringLiteral("findnext"));
+    auto *next = bar.findChild<QPushButton *>(QStringLiteral("findnext"));
 
     bar.autoSearch(QStringLiteral("FOO"));
     QVERIFY(next->isEnabled());
@@ -100,13 +87,13 @@ void FindBarBaseTest::shouldClearAllWhenShowBar()
     KSieveUi::FindBarBase bar;
     bar.show();
     QVERIFY(QTest::qWaitForWindowExposed(&bar));
-    QLabel *status = bar.findChild<QLabel *>(QStringLiteral("status"));
+    auto *status = bar.findChild<QLabel *>(QStringLiteral("status"));
     status->setText(QStringLiteral("FOO"));
     bar.closeBar();
 
     bar.show();
     bar.focusAndSetCursor();
-    PimCommon::LineEditWithCompleterNg *lineedit = bar.findChild<PimCommon::LineEditWithCompleterNg *>(QStringLiteral("searchline"));
+    auto *lineedit = bar.findChild<PimCommon::LineEditWithCompleterNg *>(QStringLiteral("searchline"));
     QVERIFY(lineedit->hasFocus());
     QVERIFY(status->text().isEmpty());
 }
