@@ -1,24 +1,10 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "vacationeditwidget.h"
-#include "vacationutils.h"
 #include "vacationmailactionwidget.h"
 #include "vacationmaillineedit.h"
 
@@ -29,7 +15,7 @@
 #include <QLineEdit>
 #include <QRegularExpressionValidator>
 
-#include <kpimtextedit/plaintexteditorwidget.h>
+#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <KPIMTextEdit/PlainTextEditor>
 #include "libksieve_debug.h"
 
@@ -51,8 +37,8 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 {
     int row = -1;
 
-    QGridLayout *glay = new QGridLayout(this);
-    glay->setContentsMargins(0, 0, 0, 0);
+    auto *glay = new QGridLayout(this);
+    glay->setContentsMargins({});
     glay->setColumnStretch(1, 1);
 
     // explanation label:
@@ -90,7 +76,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     glay->addWidget(mSubject, row, 1);
     ++row;
 
-    QHBoxLayout *timeLayout = new QHBoxLayout;
+    auto *timeLayout = new QHBoxLayout;
     // Start date
     mStartDate = new KDateComboBox(this);
     mStartDate->setObjectName(QStringLiteral("mStartDate"));
@@ -198,7 +184,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     connect(mMailActionRecipient, &VacationMailActionWidget::wasChanged, this, &VacationEditWidget::setWasChanged);
     //Add setChanged here too
 
-    QHBoxLayout *hLayout = new QHBoxLayout;
+    auto *hLayout = new QHBoxLayout;
 
     hLayout->addWidget(mMailAction);
     hLayout->addWidget(mMailActionRecipient);
